@@ -1,6 +1,6 @@
 /* Jitter: general-purpose integer arithmetic macro header.
 
-   Copyright (C) 2019, 2020 Luca Saiu
+   Copyright (C) 2019, 2020, 2021 Luca Saiu
    Written by Luca Saiu
 
    This file is part of Jitter.
@@ -323,18 +323,23 @@
      this macro may occur in inline asm operands. */           \
   ((__jitter_unsigned_type)                                    \
    ((b) == 0                                                   \
-    || ((a) == ((__jitter_signed_type)                         \
-                JITTER_MOST_NEGATIVE_SIGNED_IN_BITS (bit_no))  \
+    || ((__jitter_signed_type) (a)                             \
+        == ((__jitter_signed_type)                             \
+            JITTER_MOST_NEGATIVE_SIGNED_IN_BITS (bit_no))      \
         && (__jitter_signed_type) (b) == -1)))
 
 /* Like the previous operations, checking overflow for remainder. */
 #define JITTER_WOULD_REMAINDER_OVERFLOW(__jitter_unsigned_type,  \
                                         __jitter_signed_type,    \
                                         a, b, bit_no)            \
-  /* Remainder will overflow in the same cases as division. */   \
-  JITTER_WOULD_DIVIDED_OVERFLOW (__jitter_unsigned_type,  \
-                                 __jitter_signed_type,    \
-                                 (a), (b), (bit_no))
+  ((b) == 0)
+
+/* The non-overflow remainder condition.  See the "negative condition" comments
+   in generate-fast-branches.in.m4sh for the rationale. */
+#define JITTER_WOULD_REMAINDER_NOT_OVERFLOW(__jitter_unsigned_type,  \
+                                            __jitter_signed_type,    \
+                                            a, b, bit_no)            \
+  (b)
 
 
 
