@@ -32,20 +32,25 @@
 #include "ios.h"
 #include "ios-dev.h"
 
-#define IOS_GET_C_ERR_CHCK(c, io, off)                                \
-  {                                                                \
+#define IOS_GET_C_ERR_CHCK(c, io, off)                                 \
+  {                                                                    \
     uint8_t ch;                                                        \
-    int ret = (io)->dev_if->pread ((io)->dev, &ch, 1, off);         \
-    if (ret == IOD_EOF)                                                \
-      return IOS_EIOFF;                                                \
-    (c) = ch;                                                        \
+    int ret = (io)->dev_if->pread ((io)->dev, &ch, 1, off);            \
+    if (ret != IOD_OK && ret != IOD_EOF)                               \
+      return IOD_ERROR_TO_IOS_ERROR (ret);                             \
+    /* If the pread reports an EOF, it means the partial byte */       \
+    /* we are writing is past the end of the IOS.  That may or */      \
+    /* may not be supported in the underlying IOD, but in any */       \
+    /* case that will be resolved when the completed byte is */        \
+    /* written back.  */                                               \
+    (c) = ret == IOD_EOF ? 0 : ch;                                     \
   }
 
-#define IOS_PUT_C_ERR_CHCK(c, io, len, off)                \
-  {                                                        \
-    if ((io)->dev_if->pwrite ((io)->dev, c, len, off)      \
-        == IOD_EOF)                                        \
-      return IOS_EIOFF;                                    \
+#define IOS_PUT_C_ERR_CHCK(c, io, len, off)                     \
+  {                                                             \
+    int ret = (io)->dev_if->pwrite ((io)->dev, c, len, off);    \
+    if (ret != IOD_OK)                                          \
+      return IOD_ERROR_TO_IOS_ERROR (ret);                      \
   }
 
 /* The following struct implements an instance of an IO space.
@@ -334,6 +339,8 @@ ios_read_int_common (ios io, ios_off offset, int flags,
                      enum ios_endian endian,
                      uint64_t *value)
 {
+  int ret;
+
   /* 64 bits might span at most 9 bytes.  */
   uint8_t c[9] = {0, 0, 0, 0, 0, 0, 0, 0, 0};
 
@@ -348,8 +355,10 @@ ios_read_int_common (ios io, ios_off offset, int flags,
   lastbyte_bits = lastbyte_bits == 0 ? 8 : lastbyte_bits;
 
   /* Read the bytes and clear the unused bits.  */
-  if (io->dev_if->pread (io->dev, c, bytes_minus1 + 1, offset / 8) == IOD_EOF)
-    return IOS_EIOFF;
+  ret = io->dev_if->pread (io->dev, c, bytes_minus1 + 1, offset / 8);
+  if (ret != IOD_OK)
+    return IOD_ERROR_TO_IOS_ERROR (ret);
+
   IOS_CHAR_GET_LSB(&c[0], firstbyte_bits);
 
   switch (bytes_minus1)
@@ -698,15 +707,22 @@ ios_read_int (ios io, ios_off offset, int flags,
               enum ios_nenc nenc,
               int64_t *value)
 {
+  /* The IOS should be readable.  */
+  if (!(io->dev_if->get_flags (io->dev) & IOS_F_READ))
+    return IOS_EPERM;
+
   /* Apply the IOS bias.  */
   offset += ios_get_bias (io);
 
   /* Fast track for byte-aligned 8x bits  */
   if (offset % 8 == 0 && bits % 8 == 0)
     {
+      int ret;
       uint8_t c[8];
-      if (io->dev_if->pread (io->dev, c, bits / 8, offset / 8) == IOD_EOF)
-        return IOS_EIOFF;
+
+      ret = io->dev_if->pread (io->dev, c, bits / 8, offset / 8);
+      if (ret != IOD_OK)
+        return IOD_ERROR_TO_IOS_ERROR (ret);
 
       switch (bits) {
       case 8:
@@ -822,15 +838,22 @@ ios_read_uint (ios io, ios_off offset, int flags,
                enum ios_endian endian,
                uint64_t *value)
 {
+  /* The IOS should be readable.  */
+  if (!(io->dev_if->get_flags (io->dev) & IOS_F_READ))
+    return IOS_EPERM;
+
   /* Apply the IOS bias.  */
   offset += ios_get_bias (io);
 
   /* Fast track for byte-aligned 8x bits  */
   if (offset % 8 == 0 && bits % 8 == 0)
     {
+      int ret;
       uint8_t c[8];
-      if (io->dev_if->pread (io->dev, c, bits / 8, offset / 8) == IOD_EOF)
-        return IOS_EIOFF;
+
+      ret = io->dev_if->pread (io->dev, c, bits / 8, offset / 8);
+      if (ret != IOD_OK)
+        return IOD_ERROR_TO_IOS_ERROR (ret);
 
       switch (bits) {
       case 8:
@@ -926,6 +949,10 @@ ios_read_string (ios io, ios_off offset, int flags, char **value)
   size_t i = 0;
   int ret;
 
+  /* The IOS should be readable.  */
+  if (!(io->dev_if->get_flags (io->dev) & IOS_F_READ))
+    return IOS_EPERM;
+
   /* Apply the IOS bias.  */
   offset += ios_get_bias (io);
 
@@ -943,12 +970,9 @@ ios_read_string (ios io, ios_off offset, int flags, char **value)
                 goto error;
             }
 
-          if (io->dev_if->pread (io->dev, &str[i], 1,
-                                 offset / 8 + i) == IOD_EOF)
-            {
-              ret = IOS_EIOFF;
-              goto error;
-            }
+          ret = io->dev_if->pread (io->dev, &str[i], 1,  offset / 8 + i);
+          if (ret != IOD_OK)
+            return IOD_ERROR_TO_IOS_ERROR (ret);
         }
       while (str[i++] != '\0');
     }
@@ -971,7 +995,7 @@ ios_read_string (ios io, ios_off offset, int flags, char **value)
           ret = ios_read_uint (io, offset, flags, 8,
                                IOS_ENDIAN_MSB, /* Arbitrary.  */
                                &abyte);
-          if (ret == IOS_EIOFF)
+          if (ret == IOS_EOF)
             goto error;
 
           str[i] = (char) abyte;
@@ -994,6 +1018,7 @@ ios_write_int_fast (ios io, ios_off offset, int flags,
                     enum ios_endian endian,
                     uint64_t value)
 {
+  int ret;
   uint8_t c[8];
 
   switch (bits)
@@ -1140,8 +1165,10 @@ ios_write_int_fast (ios io, ios_off offset, int flags,
       break;
     }
 
-  if (io->dev_if->pwrite (io->dev, c, bits / 8, offset / 8) == IOD_EOF)
-    return IOS_EIOFF;
+  ret = io->dev_if->pwrite (io->dev, c, bits / 8, offset / 8);
+  if (ret != IOD_OK)
+    return IOD_ERROR_TO_IOS_ERROR (ret);
+
   return IOS_OK;
 }
 
@@ -1164,6 +1191,10 @@ ios_write_int_common (ios io, ios_off offset, int flags,
   int lastbyte_bits = (bits + (offset % 8)) % 8;
   lastbyte_bits = lastbyte_bits == 0 ? 8 : lastbyte_bits;
 
+  /* The IOS should be readable to get the completing byte.  */
+  if (!(io->dev_if->get_flags (io->dev) & IOS_F_READ))
+    return IOS_EPERM;
+
   switch (bytes_minus1)
   {
   case 0:
@@ -1504,9 +1535,10 @@ ios_write_string (ios io, ios_off offset, int flags,
       p = value;
       do
         {
-          if (io->dev_if->pwrite (io->dev, p, 1,
-                                  offset / 8 + p - value) == IOD_EOF)
-            return IOS_EIOFF;
+          int ret = io->dev_if->pwrite (io->dev, p, 1,
+                                        offset / 8 + p - value);
+          if (ret != IOD_OK)
+            return IOD_ERROR_TO_IOS_ERROR (ret);
         }
       while (*(p++) != '\0');
     }
@@ -1522,7 +1554,7 @@ ios_write_string (ios io, ios_off offset, int flags,
           int ret = ios_write_uint (io, offset, flags, 8,
                                     IOS_ENDIAN_MSB, /* Arbitrary.  */
                                     (uint64_t) *p);
-          if (ret == IOS_EIOFF)
+          if (ret == IOS_EOF)
             return ret;
 
           offset += 8;
