@@ -19,10 +19,9 @@
 #ifndef PVM_PROGRAM_H
 #define PVM_PROGRAM_H
 
+#include "pvm-program-point.h"
 #include "pvm-vm.h"
 
-typedef void *pvm_program_program_point; /* XXX better name */
-
 /* Initialize and finalize the pvm-program subsystem.  */
 
 void pvm_program_init (void);
